
.. _`WBEM subscription manager`:

WBEM subscription manager
=========================

*New in pywbem 0.9 as experimental and finalized in 0.10.*

The WBEM subscription manager API supports viewing and managing subscriptions
for indications on a WBEM server.

See :ref:`WBEM indication listener` for the API for creating and managing a
WBEM listener.


.. _`WBEMSubscriptionManager`:

WBEMSubscriptionManager
^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pywbem._subscription_manager

.. autoclass:: pywbem.WBEMSubscriptionManager
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:
